@@ -1,5 +1,5 @@
 package Net::Hadoop::YARN::DataNode::JMX;
-$Net::Hadoop::YARN::DataNode::JMX::VERSION = '0.201';
+$Net::Hadoop::YARN::DataNode::JMX::VERSION = '0.202';
 use 5.10.0;
 use strict;
 use warnings;
@@ -44,7 +44,21 @@ Net::Hadoop::YARN::DataNode::JMX
 
 =head1 VERSION
 
-version 0.201
+version 0.202
+
+=head1 SYNOPSIS
+
+    my $dn = Net::Hadoop::YARN::DataNode::JMX->new( %opt );
+
+=head1 DESCRIPTION
+
+YARN DataNode JMX methods.
+
+=head1 METHODS
+
+=head2 java_runtime
+
+    my $java = $dn->java_runtime;
 
 =head1 AUTHOR
 
