@@ -1,5 +1,5 @@
 package Net::Hadoop::YARN::ResourceManager;
-$Net::Hadoop::YARN::ResourceManager::VERSION = '0.201';
+$Net::Hadoop::YARN::ResourceManager::VERSION = '0.202';
 use strict;
 use warnings;
 use 5.10.0;
@@ -17,11 +17,24 @@ use Scalar::Util qw(
 
 with 'Net::Hadoop::YARN::Roles::Common';
 
-has '+servers' => ( default => sub { ["localhost:8088"] }, );
+has '+servers' => (
+    default => sub { ["localhost:8088"] },
+);
 
 has '+add_host_key' => ( default => sub { 1 } );
 
-
+# After CDH 5.8.2, The RM properly issues a 302 redirect, but losing any query
+# string in the original request, thus making the filters and any other parameter
+# a no-op and returning huge responses including "everything" instead of a subset.
+#
+# eg: { queue: "root.whatever" } filter will be lost after the redirect.
+#
+# We can't use active_rm() in here or in the Common role, as it will trigger a
+# deep recursion due to the fact that the HTTP calls are shared from there.
+#
+# Possibly needs to be revisited again in the future.
+#
+has '+no_http_redirect' => ( default => sub { 1 } );
 
 sub active_rm {
     my $self = shift;
@@ -50,7 +63,6 @@ sub active_rm {
     return $rv;
 }
 
-
 sub info {
     my $self = shift;
     my $opt  = is_hashref $_[0] ? shift @_ : {};
@@ -67,7 +79,6 @@ sub info {
             );
 }
 
-
 sub metrics {
     my $self = shift;
     my $opt  = is_hashref $_[0] ? shift @_ : {};
@@ -83,7 +94,6 @@ sub metrics {
             );
 }
 
-
 sub scheduler {
     my $self = shift;
     my $res  = $self->_get("cluster/scheduler");
@@ -93,7 +103,6 @@ sub scheduler {
             );
 }
 
-
 sub apps {
     my $self = shift;
     my $app_id;
@@ -119,7 +128,6 @@ sub apps {
             );
 }
 
-
 sub appattempts {
     my $self = shift;
     my $app_id = shift or die "No app ID provided";
@@ -127,7 +135,6 @@ sub appattempts {
     return $res;
 }
 
-
 # TODO check all states and add filter (validation)
 
 sub appstatistics {
@@ -156,7 +163,6 @@ sub appstatistics {
     return;
 }
 
-
 sub nodes {
     my $self = shift;
     my $node_id;
@@ -188,7 +194,6 @@ sub nodes {
 
 }
 
-
 sub _apply_host_key {
     my $self = shift;
     my $res  = shift;
@@ -234,7 +239,7 @@ Net::Hadoop::YARN::ResourceManager
 
 =head1 VERSION
 
-version 0.201
+version 0.202
 
 =head1 SYNOPSIS
 
@@ -333,6 +338,8 @@ applications matching any of the given application tags, specified as a comma-se
 
 Cluster Application Attempts API : get attempts details on a specific task
 
+=head2 appattempts
+
 =head2 appstatistics
 
 Cluster Application Statistics API
