@@ -1,5 +1,5 @@
 package Net::Hadoop::YARN::Roles::AppMasterHistoryServer;
-$Net::Hadoop::YARN::Roles::AppMasterHistoryServer::VERSION = '0.201';
+$Net::Hadoop::YARN::Roles::AppMasterHistoryServer::VERSION = '0.202';
 use strict;
 use warnings;
 use 5.10.0;
@@ -34,25 +34,47 @@ sub _mk_subs {
             my $name = $_;
             {
                 name     => $name,
-                validate => sub { shift =~ /^$validation_pattern{$name}$/ },
+                validate => sub {
+                    my $val = shift || return;
+                    $val =~ /^$validation_pattern{$name}$/
+                },
             };
         } @param_names;
 
         my $url       = $methods_urls->{$key}[0];
         my $json_path = $methods_urls->{$key}[1];
 
-        # insert the method for the endpoint in the using class
-        no strict 'refs';
-        *{ ( caller() )[0] . "::$key" } = sub {
+        my $new_method = sub {
             my $self       = shift;
             # check the list of params validates against the list of
             # placeholders gathered in the url split above
             my $params_idx = 0;
+
             for my $param ( @_ ) {
-                my $v = $validations[ $params_idx ];
+                my $v = $validations[ $params_idx ]
+                            || do {
+                                my $what = $key =~ m{ \A _ }xms
+                                         ? do {
+                                                if ( my $who = (caller 1)[3] ) {
+                                                    my($short) = (split m{ [:]{2} }xms, $who)[-1];
+                                                    sprintf qq{%s` via: `%s}, $short, $who;
+                                                }
+                                                else {
+                                                    $key;
+                                                }
+                                            }
+                                         : $key
+                                         ;
+                                die sprintf "No validator for `%s` [%s]. Be sure that `%s` is a valid API endpoint for this object",
+                                                    $param,
+                                                    $params_idx,
+                                                    $what,
+                                    ;
+                                };
+
                 if ( ! ref $param && ! $v->{validate}->( $param ) ) {
                     die sprintf "Param `%s` doesn't satisfy pattern /%s/ in call to `%s`.",
-                                    $param,
+                                    $param || '',
                                     $validation_pattern{  $v->{name}  },
                                     $key,
                     ;
@@ -77,6 +99,12 @@ sub _mk_subs {
             # Only return the JSON fragment we need
             return Hash::Path->get($res, split(/\./, $json_path));
         };
+        {
+            # limit the scope of non-strict-ness
+            # insert the method for the endpoint in the using class
+            no strict 'refs';
+            *{ ( caller() )[0] . "::$key" } = $new_method;
+        }
     }
 }
 
@@ -106,7 +134,7 @@ Net::Hadoop::YARN::Roles::AppMasterHistoryServer
 
 =head1 VERSION
 
-version 0.201
+version 0.202
 
 =head1 METHODS
 
